@@ -1,3 +1,4 @@
+from idecomp._utils.registrodecomp import RegistroDecomp
 from idecomp.decomp.modelos.dadger import LeituraDadger
 from idecomp.decomp.modelos.dadger import TE, SB, UH, CT, UE, DP, CD, PQ  # noqa
 from idecomp.decomp.modelos.dadger import RI, IA, TX, GP, NI, DT, MP, MT  # noqa
@@ -23,7 +24,7 @@ class Dadger(ArquivoRegistros):
 
     Atualmente, são suportados os registros:
     `TE`, `SB`, `UH`, `CT`, `DP`, `TX`, `GP`, `NI`, `DT`, `RE`, `LU`,
-    `VI`, `IR`, `FC`, `TI`, `HV`, `LV`, `HQ`, `LQ` e `HE`.
+    `VI`, `IR`, `FC`, `TI`, `HV`, `LV`, `HQ`, `LQ` `HE`, `EV` e `FJ`.
 
     É possível ler as informações existentes em arquivos a partir do
     método `le_arquivo()` e escreve um novo arquivo a partir do método
@@ -190,6 +191,48 @@ class Dadger(ArquivoRegistros):
                          f" para o subsistema {subsistema}" +
                          f" no estágio {estagio})")
 
+    def ac(self, uhe: int, modificacao: str) -> AC:
+        """
+        Obtém um registro que define modificações nos parâmetros
+        das UHE em um :class:`Dadger`.
+
+        :param uhe: código da UHE modificada
+        :type uhe: int
+        :param modificacao: mnemônico da modificação realizada
+        :type modificacao: str
+        :return: Um registro do tipo :class:`AC`
+        """
+        regs: List[AC] = self.__obtem_registros(AC)
+        for r in regs:
+            if all([r.uhe == uhe,
+                    r.modificacao == modificacao]):
+                return r
+        raise ValueError("Não foi encontrado registro AC" +
+                         f" para a UHE {uhe}" +
+                         f" que modifique {modificacao})")
+
+    def cd(self, numero_curva: int, subsistema: int) -> CD:
+        """
+        Obtém um registro que define as curvas de déficit
+        no estudo descrito pelo :class:`Dadger`.
+
+        :param numero_curva: Índice da curva de déficit
+            descrita
+        :type numero_curva: int
+        :param subsistema: Índice do subsistema para o qual
+            valerá a curva.
+        :type subsistema: int
+        :return: Um registro do tipo :class:`CD`
+        """
+        regs: List[CD] = self.__obtem_registros(CD)
+        for r in regs:
+            if all([r.numero_curva == numero_curva,
+                    r.subsistema == subsistema]):
+                return r
+        raise ValueError("Não foi encontrado registro CD" +
+                         f" para o subsistema {subsistema}" +
+                         f" na curva {numero_curva})")
+
     @property
     def tx(self) -> TX:
         """
@@ -633,3 +676,32 @@ class Dadger(ArquivoRegistros):
             return r
         else:
             raise ValueError("Registro não encontrado")
+
+    @property
+    def ev(self) -> EV:
+        """
+        Obtém o (único) registro que define a evaporação
+        :class:`Dadger`
+
+        :return: Um registro do tipo :class:`EV`.
+        """
+        r = self.__obtem_registro(EV)
+        return r
+
+    @property
+    def fj(self) -> FJ:
+        """
+        Obtém o (único) registro que define o arquivo `polinjus`
+        :class:`Dadger`
+
+        :return: Um registro do tipo :class:`FJ`.
+        """
+        r = self.__obtem_registro(FJ)
+        return r
+
+    def deleta_registro(self, reg: RegistroDecomp) -> bool:
+        try:
+            self._dados.registros.remove(reg)
+            return True
+        except ValueError:
+            return False
