@@ -70,6 +70,10 @@ class SB(RegistroDecomp):
         """
         return self._dados[0]
 
+    @codigo.setter
+    def codigo(self, cod: int):
+        self._dados[0] = cod
+
     @property
     def nome(self) -> str:
         """
@@ -79,6 +83,10 @@ class SB(RegistroDecomp):
         """
         return self._dados[1]
 
+    @nome.setter
+    def nome(self, n: str):
+        self._dados[1] = n
+
 
 class UH(RegistroDecomp):
     """
@@ -134,6 +142,10 @@ class UH(RegistroDecomp):
         """
         return self._dados[1]
 
+    @ree.setter
+    def ree(self, r: int):
+        self._dados[1] = r
+
     @property
     def volume_inicial(self) -> float:
         """
@@ -413,6 +425,10 @@ class DP(RegistroDecomp):
         """
         return self._dados[1]
 
+    @subsistema.setter
+    def subsistema(self, sub: int):
+        self._dados[1] = sub
+
     @property
     def num_patamares(self) -> int:
         """
@@ -504,6 +520,64 @@ class CD(RegistroDecomp):
                  f"{self._dados[9]:10.2f}" + "\n")
         arq.write(linha)
 
+    @property
+    def numero_curva(self) -> int:
+        return self._dados[0]
+
+    @numero_curva.setter
+    def numero_curva(self, n: int):
+        self._dados[0] = n
+
+    @property
+    def subsistema(self) -> int:
+        return self._dados[1]
+
+    @subsistema.setter
+    def subsistema(self, s: int):
+        self._dados[1] = s
+
+    @property
+    def nome_curva(self) -> str:
+        return self._dados[2]
+
+    @nome_curva.setter
+    def nome_curva(self, n: str):
+        self._dados[2] = n
+
+    @property
+    def estagio(self) -> int:
+        return self._dados[3]
+
+    @estagio.setter
+    def estagio(self, e: int):
+        self._dados[3] = e
+
+    @property
+    def limites_superiores(self) -> List[float]:
+        return self._dados[4::2]
+
+    @limites_superiores.setter
+    def limites_superiores(self, lim: List[float]):
+        novos = len(lim)
+        atuais = len(self.limites_superiores)
+        if novos != atuais:
+            raise ValueError("Número de limites incompatível. De" +
+                             f"vem ser fornecidos {atuais}, mas foram {novos}")
+        self._dados[4::2] = lim
+
+    @property
+    def custos(self) -> List[float]:
+        return self._dados[5::2]
+
+    @custos.setter
+    def custos(self, cus: List[float]):
+        novos = len(cus)
+        atuais = len(self.custos)
+        if novos != atuais:
+            raise ValueError("Número de custos incompatível. De" +
+                             f"vem ser fornecidos {atuais}, mas foram {novos}")
+        self._dados[5::2] = cus
+
 
 class PQ(RegistroDecomp):
     """
@@ -1516,6 +1590,54 @@ class ACPOTEFE(TipoRegistroAC):
         return linha
 
 
+class ACALTEFE(TipoRegistroAC):
+    """
+    Registro AC específico para alteração da altura efetiva
+    de queda para um conjunto de máquinas.
+    """
+    mnemonico = "ALTEFE"
+
+    def __init__(self, linha: str):
+        super().__init__(linha)
+        self._dados = [0, 0.0]
+
+    def le(self):
+        reg_usi = RegistroIn(5)
+        reg_desvio = RegistroFn(10)
+        self._dados[0] = reg_usi.le_registro(self._linha, 19)
+        self._dados[1] = reg_desvio.le_registro(self._linha, 24)
+
+    @property
+    def linha_escrita(self) -> str:
+        linha = (f"{self._dados[0]}".rjust(5) +
+                 f"{round(self._dados[1], 1)}".rjust(10))
+        return linha
+
+
+class ACVAZEFE(TipoRegistroAC):
+    """
+    Registro AC específico para alteração da vazão efetiva
+    para um conjunto de máquinas.
+    """
+    mnemonico = "VAZEFE"
+
+    def __init__(self, linha: str):
+        super().__init__(linha)
+        self._dados = [0, 0]
+
+    def le(self):
+        reg_usi = RegistroIn(5)
+        reg_vaz = RegistroIn(5)
+        self._dados[0] = reg_usi.le_registro(self._linha, 19)
+        self._dados[1] = reg_vaz.le_registro(self._linha, 24)
+
+    @property
+    def linha_escrita(self) -> str:
+        linha = (f"{self._dados[0]}".rjust(5) +
+                 f"{self._dados[1]}".rjust(5))
+        return linha
+
+
 class ACJUSMED(TipoRegistroAC):
     """
     Registro AC específico para alteração da cota média do canal
@@ -1570,7 +1692,7 @@ class ACVAZMIN(TipoRegistroAC):
 
     def le(self):
         reg_usi = RegistroIn(5)
-        if len(self._linha[19:24]) == 5:
+        if len(self._linha[19:24].strip()) > 0:
             self._dados = reg_usi.le_registro(self._linha, 19)
 
     @property
@@ -1685,6 +1807,8 @@ class AC(RegistroDecomp):
                                                  ACNUMCON,
                                                  ACNUMMAQ,
                                                  ACPOTEFE,
+                                                 ACALTEFE,
+                                                 ACVAZEFE,
                                                  ACJUSMED,
                                                  ACVERTJU,
                                                  ACVAZMIN,
@@ -1747,6 +1871,22 @@ class AC(RegistroDecomp):
         linha += "\n"
         arq.write(linha)
 
+    @property
+    def uhe(self) -> int:
+        return self._dados[0]
+
+    @uhe.setter
+    def uhe(self, u: int):
+        self._dados[0] = u
+
+    @property
+    def modificacao(self) -> str:
+        return self._dados[1]
+
+    @modificacao.setter
+    def modificacao(self, m: str):
+        self._dados[1] = m
+
 
 class IR(RegistroDecomp):
     """
@@ -1914,7 +2054,7 @@ class FC(RegistroDecomp):
 
     def le(self):
         reg_mne = RegistroAn(6)
-        reg_nome = RegistroAn(60)
+        reg_nome = RegistroAn(200)
         self._dados[0] = reg_mne.le_registro(self._linha, 4)
         self._dados[1] = reg_nome.le_registro(self._linha, 14)
 
@@ -2461,6 +2601,22 @@ class EV(RegistroDecomp):
                  f"{self._dados[1]}".rjust(3) + "\n")
         arq.write(linha)
 
+    @property
+    def modelo(self) -> int:
+        return self._dados[0]
+
+    @modelo.setter
+    def modelo(self, m: int):
+        self._dados[0] = m
+
+    @property
+    def volume_referencia(self) -> str:
+        return self._dados[1]
+
+    @volume_referencia.setter
+    def volume_referencia(self, v: str):
+        self._dados[1] = v
+
 
 class FJ(RegistroDecomp):
     """
@@ -2481,6 +2637,14 @@ class FJ(RegistroDecomp):
                  f"{self.dados}".rjust(12) + "\n")
         arq.write(linha)
 
+    @property
+    def arquivo(self) -> str:
+        return self._dados
+
+    @arquivo.setter
+    def arquivo(self, a: str):
+        self._dados = a
+
 
 class HE(RegistroDecomp):
     """
